Package: ROntoTools
Type: Package
Title: R Onto-Tools suite
Version: 2.38.0
Author: Calin Voichita <calin@wayne.edu> and Sahar Ansari
    <saharansari@wayne.edu> and Sorin Draghici <sorin@advaitabio.com>
Maintainer: Sorin Draghici <sorin@advaitabio.com>
Description: Suite of tools for functional analysis.
biocViews: NetworkAnalysis, Microarray, GraphsAndNetworks
License: CC BY-NC-ND 4.0 + file LICENSE
Depends: methods, graph, boot, KEGGREST, KEGGgraph, Rgraphviz
Suggests: RUnit, BiocGenerics
RoxygenNote: 5.0.1
git_url: https://git.bioconductor.org/packages/ROntoTools
git_branch: RELEASE_3_22
git_last_commit: 5e9ce05
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.22
Date/Publication: 2025-10-29
NeedsCompilation: no
Packaged: 2025-10-30 06:09:13 UTC; biocbuild
